#
# spec file for package kubeone
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# https://github.com/kubermatic/kubeone/blob/main/Makefile#L40
# curl -SsL https://dl.k8s.io/release/stable-1.31.txt
%define KUBERNETES_STABLE_VERSION v1.31.3

Name:           kubeone
Version:        1.11.1
Release:        1.1
Summary:        CLI for the kubeone cluster automation
License:        Apache-2.0
URL:            https://github.com/kubermatic/kubeone
Source:         kubeone-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23.4
BuildRequires:  zsh

%description
Kubermatic KubeOne automates cluster operations on all your cloud, on-prem,
edge, and IoT environments. KubeOne can install high-available (HA) master
clusters as well single master clusters.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X k8c.io/kubeone/pkg/cmd.defaultKubeVersion=%{KUBERNETES_STABLE_VERSION} \
   -X k8c.io/kubeone/pkg/cmd.version=v%{version} \
   -X k8c.io/kubeone/pkg/cmd.commit=${COMMIT_HASH} \
   -X k8c.io/kubeone/pkg/cmd.date=${BUILD_DATE}" \
   -o bin/kubeone

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Jul 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.11.1:
  * Bug or Regression
  - Fix CSI snapshot webhook name for Nutanix (#3761, @kron4eg)
* Fri Jul 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.11.0:
  * Feature
  - Automate caBundle injection to the PodSpec of addons (#3683,
    @kron4eg)
  - Add CA Config API
  - Deprecate CABundle field (#3647, @kron4eg)
  - Add --insecure flag to mirror-images command to bypass TLS
    verification (#3657, @mohamed-rafraf)
  - Add support for kubernetes version 1.33. (#3651, @soer3n)
  - Add the ability to override containerd sandbox image (#3646,
    @mohamed-rafraf)
  - Allow control-plane and static workers nodes annotation
    (#3658, @kron4eg)
  - Introduce mirror-images command to mirror images used by
    kubeone into another registry (#3631, @mohamed-rafraf)
  - Support KubeVirt CCM Deployment (#3661, @moadqassem)
  * Bug or Regression
  - Bump helm.sh/helm/v3 to v3.18.4 (#3744, @dependabot[bot])
  - Controlplane nodes will now have the
    fs.inotify.max_user_instances limit increased aswell (#3649,
    @4ch3los)
  - Drop kubevirt infraClusterKubeconfig API fields (#3674,
    @kron4eg)
  - Fix CABundle flag for OSM (#3642, @kron4eg)
  - Fix Canal dualstack setup (#3747, @kron4eg)
  - Fixes the vsphere-config-secret name misalignment across
    vSphere CSI driver components. (#3745, @rajaSahil)
  * Chore
  - Update GCP CSI manifests reference to v1.20.0
  - Update OpenStack CSI driver to v2.33.0
  - Update OpenStack CCM to v2.33.0
  - Update Hetzner CSI driver to v2.16.0
  - Update Hetzner CCM to v1.25.1
  - Update vSphere CSI driver to v3.5.0
  - Update Azure Disk CSI drive to v1.33.1
  - Update CSI Azure File driver to v1.33.2
  - Update Azure CCM to v1.33.1
  - Update AWS CSI to v1.45.0
  - Update AWS CCM
  - Update calico CNI v3.30.2 (#3683, @kron4eg)
  - Bump Go version to 1.24.4 (#3682, @archups)
  - Bump OSM to v1.7.2 and MC to v1.62.0 (#3725, @archups)
  - Bump operating-system-manager to v1.7.4 (#3738, @archups)
  - Images updates:
  - Calico / Canal v3.30.0
  - Cilium: v1.17.3
  - cluster-autoscaler: v1.30.4
  - cluster-autoscaler: v1.31.2
  - cluster-autoscaler: v1.32.1
  - AWS CCM: v1.33.0
  - AWS Ebs Csi: v1.43.0
  - AWS Ebs Csi Attacher: v4.8.1-eks-1-33-2
  - AWS Ebs Csi Livenessprobe: v2.15.0-eks-1-33-3
  - AWS Ebs Csi Node Driver Registrar: v2.13.0-eks-1-33-2
  - AWS Ebs Csi External Provisioner: v5.2.0-eks-1-33-3
  - AWS Ebs Csi External Resizer: v1.13.2-eks-1-33-3
  - Azure CCM: v1.30.12
  - Azure CCM: v1.31.6
  - Azure CCM: v1.32.5
  - Azure CCM: v1.33.0
  - Azure CNM: v1.30.12
  - Azure CNM: v1.31.6
  - Azure CNM: v1.32.5
  - Azure CNM: v1.33.0
  - Azure Disk CSI: v1.33.0
  - Azure File CSI: v1.33.0
  - Digitalocean CSI Attacher: vv4.8.1
  - Digitalocean CSI Provisioner: v5.2.0
  - Digitalocean CSI Resizer: v1.13.2
  - Digitalocean CSI Snapshotter: v8.2.1
  - Hetzner CCM: v1.24.
  - OpenstackCCM: v1.30.3
  - OpenstackCCM: v1.31.2
  - OpenStack Cinder CSI: v1.30.3
  - OpenStack Cinder CSI: v1.31.3
  - Vsphere CCM; v1.30.2
  - Vsphere CCM; v1.31.1
  - Vsphere CCM; v1.32.1
  - Vsphere CCM; v1.33.0
  - Vsphere CSI Driver: v3.4.0
  - Vsphere CSI Syncer: v3.4.0
  - Vsphere CSI Attacher: v4.8.1
  - Vsphere CSI Livenessprobe: v2.15.0
  - Vsphere CSI Node Driver Registrar: v2.13.0
  - Vsphere CSI Provisioner; v5.2.0
  - Vsphere CSI Resizer: v1.13.2
  - Vsphere CSI Snapshotter: v8.2.1
  - GCP CCM: v32.2.2
  - GCP Compute CSI Driver: v1.15.4
  - GCP Compute CSI Provisioner: v5.2.0
  - GCP Compute CSI Attacher: v4.8.1
  - GCP Compute CSI Resizer v1.13.2
  - GCP Compute CSI Snapshotter: v8.2.1
  - GCP Compute CSI Node Driver Registrar: v2.13.0
  - Restic: v0.17.3
  - CSI external snapshot: v8.2.1
  - Cilium Hubble: v0.13.2 (#3653, @soer3n)
  - OperatingSystemManager v1.6.5
  - DigitalOcean CCM: v1.59.0
  - DigitalOcean CSI Plugin: v4.14.0 (#3660, @soer3n)
  - Update Hetzner CCM to the v1.26.0 (#3732, @kron4eg)
  - Update Flannel CNI to v0.24.4 (#3736, @kron4eg)
  - Update MachineController to v1.61.3 (#3672, @xmudrii)
  - Update to Go 1.24.2 (#3618, @xrstf)
  * Other (Cleanup or Flake)
  - Make kubeone go installa-ble again (#3648, @kron4eg)
* Fri Jun 13 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.10.1:
  * Urgent Upgrade Notes
    (No, really, you MUST read this before you upgrade)
  - KubeVirt Cloud Controller Manager (CCM) is now deployed by
    default for all KubeVirt clusters. Two new fields are added
    to the API used to configure the CCM
    (.cloudProvider.kubevirt.zoneAndRegionEnabled and
    .cloudProvider.kubevirt.loadBalancerEnabled).
    .cloudProvider.kubevirt.infraNamespace is now a required
    field and KubeOne will fail validation if not set (#3661,
    @moadqassem)
  - [ACTION REQUIRED] The KubeVirt CCM requires some permissions
    to be added to the ServiceAccount that is bound to the
    infrastructure cluster kubeconfig in order to perform some
    tasks on the infrastructure side. For more information about
    the required roles please check this file
  - [ACTION REQUIRED] The
    .cloudProvider.kubevirt.infraClusterKubeconfig field has been
    removed from the KubeOneCluster type. Users must remove this
    field from their KubeOneCluster manifests otherwise the
    runtime validation will fail. The kubeconfig file provided
    via the KUBEVIRT_KUBECONFIG environment variable is used as a
    kubeconfig file for the infrastructure cluster (#3675,
    @kron4eg)
  * API Changes
  - Add a new annotations field to HostConfig used to annotate
    control plane and static worker nodes (#3658, @kron4eg)
  * Bug or Regression
  - Fix incorrect CABundle flag in the operating-system-manager
    (OSM) Deployment (#3644, @kubermatic-bot)
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.10.0:
  https://github.com/kubermatic/kubeone/releases/tag/v1.10.0
  Upgrade notes:
  https://docs.kubermatic.com/kubeone/v1.10/tutorials/upgrading/upgrading-from-1.9-to-1.10/
  Urgent Upgrade Notes
  (No, really, you MUST read this before you upgrade)
  * Disallow using machine-controller and operating-system-manager
    with the cloud provider none (.cloudProvider.none). If you're
    affected by this change, you have to either disable
    machine-controller and/or operating-system-manager, or switch
    from the cloud provider none to a supported cloud provider
    (#3369, @kron4eg)
  * The Calico VXLAN optional addon has been removed from KubeOne.
    This addon has been non-functional for the past several
    releases. If you still need and use this addon, we advise using
    the addons mechanism to deploy it (#3568, @kron4eg)
  * The minimum kernel version for Kubernetes 1.32+ clusters is
    4.19. Trying to provision a cluster with Kubernetes 1.32 or
    upgrade an existing cluster to Kubernetes 1.32, where nodes are
    not satisfying this requirement, will result in a pre-flight
    check failure (#3590, @kron4eg)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.9.2:
  * Add changelog for v1.9.2 (#3551)
  * include the infra namespace as a pod namespace for machine
    controller webhook (#3549)
  * [release/v1.9] Cherry-pick the required fixes for the
    `release/v1.9` branch (#3547)
  * [release/v1.9] Synchronize OWNERS_ALIASES file with Github
    teams (#3543)
  * [release/v1.9] Synchronize OWNERS_ALIASES file with Github
    teams (#3532)
  * [release/v1.9] Fix APT/RPM PGP key expiration issue for old
    kubernetes versiosn (#3526)
  * Update codegen with copyright YEAR (#3527)
* Mon Dec 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.1:
  * Update changelog for 1.9.1 (#3515) (#3518)
  * [release/v1.9] Update Go to 1.23.4, /x/net to v0.33.0, and
    /x/crypto to v0.31.0 (#3513)
  * [release/v1.9] Support the deployment of KubeVirt CSI driver
    (#3512)
  * Determine OS for Docker repo programmatically (#3511)
  * Remove Docker GPG key before dearmor-ing it (#3506)
  * add support for KubeVirt namespaced mode in Kubeone (#3503)
  * update changelog for v1.9.1 (#3501)
  * Change release date for v1.9.1 (#3497)
  * Add changelog for v1.9.1 (#3493)
  * chores(ccm): update openstack version for 1.30 and 1.31 (#3489)
  * Use dedicated keyring for docker packages (#3485)
  * return empty list instead of nil to not break the ui (#3480)
  * [release/v1.9] Synchronize OWNERS_ALIASES file with Github
    teams (#3475)
* Fri Nov 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.0:
  * Urgent Upgrade Notes
    https://docs.kubermatic.com/kubeone/v1.9/tutorials/upgrading/upgrading-from-1.8-to-1.9/
    (No, really, you MUST read this before you upgrade)
  - Add support for Ubuntu 24.04. Example Terraform configs for
    all providers are now using Ubuntu 24.04 by default. If
    you're using the latest Terraform configs with an existing
    cluster, make sure to bind the operating system/image to the
    image that you're currently using, otherwise your
    instances/cluster might get recreated by Terraform. On some
    providers, machine-controller will use Ubuntu 24.04 if the
    image is not explicitly specified. (#3302, @SimonTheLeg)
  - Example Terraform configs for Hetzner are now using cx22
    instead of cx21 instance type by default. If you use the
    latest Terraform configs with an existing cluster, make sure
    to override the instance type as needed, otherwise your
    instances/cluster might get recreated by Terraform. (#3370,
    @kron4eg)
  - KubeOne is now validating that IP addresses and hostnames
    provided for control plane nodes and static worker nodes are
    different. In other words, it's not possible to use the same
    machine both as a control plane node and a static worker
    node. This behavior has never been supported by KubeOne; if
    you want a control plane node that can schedule any pod, you
    can provision it as a control plane node and remove the
    control plane taint
    (node-role.kubernetes.io/control-plane:NoSchedule). (#3334,
    @kron4eg)
  - Update Cilium to v1.16.3. This change might affect users that
    have nodes that are low on capacity (pods or resources wise).
    The Cilium architecture has been changed so that the Envoy
    Proxy is not integrated into Cilium, but is a dedicated
    component/DaemonSet. If you have nodes that are low on
    capacity, you might encounter issues when trying to start
    Envoy Proxy pods on those nodes. In this case, you'll need to
    override the Cilium addon to use the old architecture with
    Envoy Proxy integrated into Cilium. (#3415, @xmudrii) kubeone
    install and kubeone upgrade subcommands are removed. We have
    deprecated these commands in KubeOne 1.4, and made them
    hidden in KubeOne 1.5. With this change, we're permanently
    removing these two commands. kubeone apply should be used
    instead. (#3349, @mohamed-rafraf)
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.3:
  * Add changelog for v1.8.3 (#3381)
  * Update vSphere images to use our mirror (#3378)
  * Replace deprecated Hetzner (in fact, restricted) cx21 instance
    type with cx22 (#3371)
  * [release/v1.8] Synchronize OWNERS_ALIASES file with Github
    teams (#3363)
* Fri Aug  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.2:
  * Add changelog for v1.8.2 (#3341)
  * Remove centos7 e2e tests (#3335)
  * CentOS docker repo being abandoned, replaced with RHEL (#3336)
  * [release/v1.8] Update machine-controller to 1.59.3 (#3323)
  * Set HttpPutResponseHopLimit to 3 by default for AWS nodes
    (#3329)
  * [release/v1.8] Update calico CNI to fix CPU issues (#3326)
  * Minor fix to the cluster autoscaler docs (#3315)
  * Allow upstream cluster autoscaler flags configuration (#3306)
  * do not put multiple identical tolerations on the CoreDNS
    deployment (#3298)
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.1:
  * Add release date for 1.8.1 (#3294)
  * Remove release date for 1.8.1 (#3292)
  * Add changelog for v1.8.1 (#3288)
  * Don't downgrade GCP CCM for v1.27 clusters (#3284)
  * Bind csi-snapshotter to v8.0.1 for GCE (#3281)
  * Documentation for VMware Cloud Director (#3278)
  * Be explicit about bastion type, as not OSes support nano size
    (#3276)
  * [release/v1.8] Fix snapshot-webhook admitting non-supported
    objects and add default VolumeSnapshotClass for all supported
    providers (#3275)
  * Fix openstack CCM addon (#3274)
  * Bind csi-snapshotter to v8.0.1 (#3270)
  * fix local helm releases deletion issue (#3268)
  * Increase TEST_TIMEOUT to 90m for stable tests infrastructure
    (#3267)
  * [release/v1.8] Use the same bastion_type on AWS as worker_type
    (#3264)
  * Fix default rockylinux EC2 image filter query (#3262)
  * Refactor the upgrade process to stop using config on upgrade
    (#3253)
  * change order of ensureCABundleConfigMap task (#3247)
  * [release/v1.8] Improve the Kubernetes 1.30 support (#3242)
  * [release/v1.8] bump GCP CCM to 30.x, using staging images
    (#3241)
  * install apparmor-utils in ubuntu (#3235)
  * [release/v1.8] Update images to support Kubernetes 1.30 (#3230)
  * [release/v1.8] Kubernetes 1.30 support (#3215)
  * Update canal to v3.27.3 (#3200)
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  Urgent Upgrade Notes
  (No, really, you MUST read this before you upgrade)
  * Refactor example Terraform configs for Hetzner to randomly
    generate the private network subnet in order to support
    creating multiple KubeOne clusters (#3152, @xmudrii)
  * The example Terraform configs for Azure have been migrated to
    use the Standard SKU for IP addresses. This is a breaking
    change for existing setups; in which case you should continue
    using your current SKU. Manual migration is possible by
    dissociating IP from the VM and LB, the migrating it, and
    assigning it back, however please consider all potential risks
    before doing this migration (#3149, @kron4eg)
  * Credentials defined in the credentials file now have precedence
    over credentials defined via environment variables. This change
    is made to match the behavior that's already documented in the
    KubeOne docs. If you use both the credentials file and the
    environment variables, we recommend double-checking your
    credentials file to make sure the credentials are up to date,
    as those credentials will be applied on the next kubeone apply
    run (#2991, @kron4eg)
  * kured has been removed, you have to re-enable it back in form
    of helmRelease (#3024, @kron4eg)
  * OSM: The latest Ubuntu 22.04 images on Azure have modified the
    configuration for cloud-init and how it accesses its datasource
    in Azure, in a breaking way. If you're having an Azure cluster,
    it's required to refresh your machines with the latest provided
    OSPs to ensure that a system-wide package update doesn't result
    in broken machines. (#3172, @xrstf)
  * Support for Docker is removed; containerRuntime.docker became a
    no-op. (#3008, @kron4eg)
* Thu May  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.4:
  * CHANGELOG: Add changelog for v1.7.4 (#3168)
  * [release/v1.7] bump OSM to 1.3.5 (#3163)
  * [release/v1.7] Clean `yum` caches when configuring repos
    (#3147)
  * [release/v1.7] fix: debian apt-get update running before
    configuring repositories (#3084)
  * Deploy User defined addons before external CCM initialization
    (#3068)
  * Update MC to v1.57.6 (#3064)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.3:
  * Add changelog for v1.7.3 (#3063)
  * Update Go to 1.21.6 (#3060)
  * Update machine-controller to v1.57.5 (#3057)
  * Improve error messaging when working with remote files over SSH
    (#3054)
  * [release/v1.7]  Fix Flatcar torcx issues (#3041)
  * fix strictArp field usage (#3006)
  * Define fixed etcd versions (#3004)
  * Fix helm deploying resources in the wrong namespace (#3001)
* Mon Jan 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubeone: CLI for the kubeone cluster automation
